@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2014, CRS4
+# Copyright (c) 2012-2015, CRS4
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy of
 # this software and associated documentation files (the "Software"), to deal in
@@ -20,24 +20,20 @@
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 MESSAGES = {'ACK': ('sequence', (('MSH', (1, 1)), ('MSA', (1, 1)), ('ERR', (0, 1)))),
- 'ADR_A19': ('sequence',
-             (('MSH', (1, 1)),
-              ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
-              ('QRD', (1, 1)),
-              ('ADR_A19_QUERY_RESPONSE', (1, -1)),
-              ('DSC', (0, 1)))),
  'ADT_A01': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('NK1', (0, -1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
               ('AL1', (0, -1)),
               ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
+              ('DRG', (0, 1)),
+              ('ADT_A01_PROCEDURE', (0, -1)),
               ('GT1', (0, -1)),
               ('ADT_A01_INSURANCE', (0, -1)),
               ('ACC', (0, 1)),
@@ -47,352 +43,190 @@ MESSAGES = {'ACK': ('sequence', (('MSH', (1, 1)), ('MSA', (1, 1)), ('ERR', (0, 1
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)))),
  'ADT_A03': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, 1)),
+              ('ADT_A03_PROCEDURE', (0, -1)),
               ('OBX', (0, -1)))),
- 'ADT_A04': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A04_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A05': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A05_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
  'ADT_A06': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('MRG', (0, 1)),
               ('NK1', (0, -1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
+              ('DRG', (0, 1)),
               ('OBX', (0, -1)),
               ('AL1', (0, -1)),
               ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
+              ('DRG', (0, 1)),
+              ('ADT_A06_PROCEDURE', (0, -1)),
               ('GT1', (0, -1)),
               ('ADT_A06_INSURANCE', (0, -1)),
               ('ACC', (0, 1)),
               ('UB1', (0, 1)),
               ('UB2', (0, 1)))),
- 'ADT_A07': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('MRG', (0, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A07_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A08': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A08_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
  'ADT_A09': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('DG1', (0, -1)))),
- 'ADT_A10': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('DG1', (0, -1)))),
- 'ADT_A11': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
               ('DG1', (0, -1)))),
  'ADT_A12': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
-              ('DG1', (0, -1)))),
- 'ADT_A13': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A13_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A14': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A14_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A15': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('DG1', (0, -1)))),
+              ('DG1', (0, 1)))),
  'ADT_A16': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
-              ('DG1', (0, -1)))),
+              ('DG1', (0, 1)),
+              ('DRG', (0, 1)))),
  'ADT_A17': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)))),
  'ADT_A18': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('MRG', (0, 1)),
               ('PV1', (1, 1)))),
  'ADT_A20': ('sequence', (('MSH', (1, 1)), ('EVN', (1, 1)), ('NPU', (1, 1)))),
- 'ADT_A21': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A22': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A23': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
  'ADT_A24': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('PV1', (0, 1)),
+              ('DB1', (0, -1)),
               ('PID', (1, 1)),
-              ('PV1', (0, 1)))),
- 'ADT_A25': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A26': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A27': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A28': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('NK1', (0, -1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
-              ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A28_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A29': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
+              ('PD1', (0, 1)),
+              ('PV1', (0, 1)),
+              ('DB1', (0, -1)))),
  'ADT_A30': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
+              ('PD1', (0, 1)),
               ('MRG', (1, 1)))),
- 'ADT_A31': ('sequence',
+ 'ADT_A38': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
-              ('NK1', (0, -1)),
+              ('PD1', (0, 1)),
               ('PV1', (1, 1)),
               ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
               ('OBX', (0, -1)),
-              ('AL1', (0, -1)),
               ('DG1', (0, -1)),
-              ('PR1', (0, -1)),
-              ('GT1', (0, -1)),
-              ('ADT_A31_INSURANCE', (0, -1)),
-              ('ACC', (0, 1)),
-              ('UB1', (0, 1)),
-              ('UB2', (0, 1)))),
- 'ADT_A32': ('sequence',
+              ('DRG', (0, 1)))),
+ 'ADT_A39': ('sequence',
+             (('MSH', (1, 1)), ('EVN', (1, 1)), ('ADT_A39_PATIENT', (1, -1)))),
+ 'ADT_A43': ('sequence',
+             (('MSH', (1, 1)), ('EVN', (1, 1)), ('ADT_A43_PATIENT', (1, -1)))),
+ 'ADT_A45': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A33': ('sequence',
+              ('PD1', (0, 1)),
+              ('ADT_A45_MERGE_INFO', (1, -1)))),
+ 'ADT_A50': ('sequence',
              (('MSH', (1, 1)),
               ('EVN', (1, 1)),
               ('PID', (1, 1)),
-              ('PV1', (1, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)))),
- 'ADT_A34': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('MRG', (1, 1)))),
- 'ADT_A35': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('MRG', (1, 1)))),
- 'ADT_A36': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('MRG', (1, 1)))),
- 'ADT_A37': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (0, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (0, 1)))),
- 'BAR_P01': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('BAR_P01_VISIT', (1, -1)))),
- 'BAR_P02': ('sequence',
-             (('MSH', (1, 1)), ('EVN', (1, 1)), ('BAR_P02_PATIENT', (1, -1)))),
- 'DFT_P03': ('sequence',
-             (('MSH', (1, 1)),
-              ('EVN', (1, 1)),
-              ('PID', (1, 1)),
-              ('PV1', (0, 1)),
-              ('PV2', (0, 1)),
-              ('OBX', (0, -1)),
-              ('FT1', (1, -1)))),
- 'DSR_P04': ('sequence',
+              ('PD1', (0, 1)),
+              ('MRG', (1, 1)),
+              ('PV1', (1, 1)))),
+ 'ARD_A19': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
               ('ERR', (0, 1)),
               ('QRD', (1, 1)),
               ('QRF', (0, 1)),
-              ('DSP', (1, -1)),
+              ('ARD_A19_QUERY_RESPONSE', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'BAR_P01': ('sequence',
+             (('MSH', (1, 1)),
+              ('EVN', (1, 1)),
+              ('PID', (1, 1)),
+              ('PD1', (0, 1)),
+              ('BAR_P01_VISIT', (1, -1)))),
+ 'BAR_P02': ('sequence',
+             (('MSH', (1, 1)), ('EVN', (1, 1)), ('BAR_P02_PATIENT', (1, -1)))),
+ 'BAR_P06': ('sequence',
+             (('MSH', (1, 1)), ('EVN', (1, 1)), ('BAR_P06_PATIENT', (1, -1)))),
+ 'CRM_C01': ('sequence', (('MSH', (1, 1)), ('CRM_C01_PATIENT', (1, -1)))),
+ 'CSU_C09': ('sequence', (('MSH', (1, 1)), ('CSU_C09_PATIENT', (1, -1)))),
+ 'DFT_P03': ('sequence',
+             (('MSH', (1, 1)),
+              ('EVN', (1, 1)),
+              ('PID', (1, 1)),
+              ('PD1', (0, 1)),
+              ('PV1', (0, 1)),
+              ('PV2', (0, 1)),
+              ('DB1', (0, -1)),
+              ('OBX', (0, -1)),
+              ('DFT_P03_FINANCIAL', (1, -1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, 1)),
+              ('GT1', (0, -1)),
+              ('DFT_P03_INSURANCE', (0, -1)),
+              ('ACC', (0, 1)))),
+ 'DOC_T12': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QRD', (1, 1)),
+              ('DOC_T12_RESULT', (1, -1)),
               ('DSC', (0, 1)))),
  'DSR_Q01': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
               ('ERR', (0, 1)),
+              ('QAK', (0, 1)),
               ('QRD', (1, 1)),
               ('QRF', (0, 1)),
               ('DSP', (1, -1)),
@@ -400,36 +234,48 @@ MESSAGES = {'ACK': ('sequence', (('MSH', (1, 1)), ('MSA', (1, 1)), ('ERR', (0, 1
  'DSR_Q03': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (0, 1)),
+              ('ERR', (0, 1)),
+              ('QAK', (0, 1)),
               ('QRD', (1, 1)),
               ('QRF', (0, 1)),
               ('DSP', (1, -1)),
               ('DSC', (0, 1)))),
- 'DSR_R03': ('sequence',
-             (('MSH', (1, 1)),
-              ('MSA', (0, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
-              ('DSP', (1, -1)),
-              ('DSC', (0, 1)))),
- 'MFD_M01': ('sequence', (('MSH', (1, 1)), ('MFI', (1, 1)), ('MFA', (0, -1)))),
- 'MFD_M02': ('sequence', (('MSH', (1, 1)), ('MFI', (1, 1)), ('MFA', (0, -1)))),
- 'MFD_M03': ('sequence', (('MSH', (1, 1)), ('MFI', (1, 1)), ('MFA', (0, -1)))),
- 'MFK_M01': ('sequence',
+ 'EDR_Q01': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
               ('ERR', (0, 1)),
+              ('QAK', (1, 1)),
+              ('DSP', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'EQQ_Q01': ('sequence', (('MSH', (1, 1)), ('EQL', (1, 1)), ('DSC', (0, 1)))),
+ 'ERP_Q01': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QAK', (1, 1)),
+              ('ERQ', (1, 1)),
+              ('DSC', (0, 1)))),
+ 'MDM_T01': ('sequence',
+             (('MSH', (1, 1)),
+              ('EVN', (1, 1)),
+              ('PID', (1, 1)),
+              ('PV1', (1, 1)),
+              ('TXA', (1, 1)))),
+ 'MDM_T02': ('sequence',
+             (('MSH', (1, 1)),
+              ('EVN', (1, 1)),
+              ('PID', (1, 1)),
+              ('PV1', (1, 1)),
+              ('TXA', (1, 1)),
+              ('OBX', (1, -1)))),
+ 'MFK_M01': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
               ('MFI', (1, 1)),
               ('MFA', (0, -1)))),
  'MFK_M02': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
-              ('MFI', (1, 1)),
-              ('MFA', (0, -1)))),
- 'MFK_M03': ('sequence',
-             (('MSH', (1, 1)),
-              ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
               ('MFI', (1, 1)),
               ('MFA', (0, -1)))),
  'MFN_M01': ('sequence',
@@ -440,87 +286,162 @@ MESSAGES = {'ACK': ('sequence', (('MSH', (1, 1)), ('MSA', (1, 1)), ('ERR', (0, 1
               ('MFN_M02_MF_STAFF', (1, -1)))),
  'MFN_M03': ('sequence',
              (('MSH', (1, 1)), ('MFI', (1, 1)), ('MFN_M03_MF_TEST', (1, -1)))),
- 'MFQ_M01': ('sequence',
+ 'MFN_M05': ('sequence',
              (('MSH', (1, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
-              ('DSC', (0, 1)))),
- 'MFQ_M02': ('sequence',
-             (('MSH', (1, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
-              ('DSC', (0, 1)))),
- 'MFQ_M03': ('sequence',
-             (('MSH', (1, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
-              ('DSC', (0, 1)))),
- 'MFR_M01': ('sequence',
-             (('MSH', (1, 1)),
-              ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
               ('MFI', (1, 1)),
-              ('MFR_M01_MF', (1, -1)),
-              ('DSC', (0, 1)))),
- 'MFR_M02': ('sequence',
+              ('MFN_M05_MF_LOCATION', (1, -1)))),
+ 'MFN_M06': ('sequence',
+             (('MSH', (1, 1)), ('MFI', (1, 1)), ('MFN_M06_MF_CDM', (1, -1)))),
+ 'MFN_M07': ('sequence',
              (('MSH', (1, 1)),
-              ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
               ('MFI', (1, 1)),
-              ('MFR_M02_MF_STAFF', (1, -1)),
-              ('DSC', (0, 1)))),
- 'MFR_M03': ('sequence',
+              ('MFN_M07_MF_CLIN_STUDY', (1, -1)))),
+ 'MFN_M08': ('sequence',
              (('MSH', (1, 1)),
-              ('MSA', (1, 1)),
-              ('ERR', (0, 1)),
-              ('QRD', (1, 1)),
-              ('QRF', (0, 1)),
               ('MFI', (1, 1)),
-              ('MFR_M03_MF_TEST', (1, -1)),
-              ('DSC', (0, 1)))),
- 'NMD_N01': ('sequence',
+              ('MFN_M08_MF_TEST_NUMERIC', (1, -1)))),
+ 'MFN_M09': ('sequence',
              (('MSH', (1, 1)),
-              ('NMD_N01_CLOCK_AND_STATS_WITH_NOTES', (1, -1)))),
- 'NMQ_N02': ('sequence',
+              ('MFI', (1, 1)),
+              ('MFN_M09_MF_TEST_CATEGORICAL', (1, -1)))),
+ 'MFN_M10': ('sequence',
              (('MSH', (1, 1)),
-              ('NMQ_N02_QRY_WITH_DETAIL', (0, 1)),
-              ('NMQ_N02_CLOCK_AND_STATISTICS', (1, -1)))),
- 'NMR_N02': ('sequence',
+              ('MFI', (1, 1)),
+              ('MFN_M10_MF_TEST_BATTERIES', (1, -1)))),
+ 'MFN_M11': ('sequence',
+             (('MSH', (1, 1)),
+              ('MFI', (1, 1)),
+              ('MFN_M11_MF_TEST_CALCULATED', (1, -1)))),
+ 'OMD_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('OMD_O01_PATIENT', (0, 1)),
+              ('OMD_O01_ORDER_DIET', (1, -1)),
+              ('OMD_O01_ORDER_TRAY', (0, -1)))),
+ 'OMN_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('OMN_O01_PATIENT', (0, 1)),
+              ('OMN_O01_ORDER', (1, -1)))),
+ 'OMS_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('OMS_O01_PATIENT', (0, 1)),
+              ('OMS_O01_ORDER', (1, -1)))),
+ 'ORD_O02': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
               ('ERR', (0, 1)),
-              ('QRD', (0, 1)),
-              ('NMR_N02_CLOCK_AND_STATS_WITH_NOTES_ALT', (1, -1)))),
+              ('NTE', (0, -1)),
+              ('ORD_O02_RESPONSE', (0, 1)))),
  'ORF_R04': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
               ('ORF_R04_QUERY_RESPONSE', (1, -1)),
-              ('ORF_R04_ORDER', (1, -1)),
               ('DSC', (0, 1)))),
  'ORM_O01': ('sequence',
              (('MSH', (1, 1)),
               ('NTE', (0, -1)),
               ('ORM_O01_PATIENT', (0, 1)),
               ('ORM_O01_ORDER', (1, -1)))),
+ 'ORN_O02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('ORN_O02_RESPONSE', (0, 1)))),
  'ORR_O02': ('sequence',
              (('MSH', (1, 1)),
               ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
               ('NTE', (0, -1)),
-              ('ORR_O02_PATIENT', (0, 1)))),
+              ('ORR_O02_RESPONSE', (0, 1)))),
  'ORU_R01': ('sequence',
              (('MSH', (1, 1)),
-              ('ORU_R01_PATIENT_RESULT', (1, -1)),
+              ('ORU_R01_RESPONSE', (1, -1)),
               ('DSC', (0, 1)))),
- 'QRY_A19': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (0, 1)))),
- 'QRY_P04': ('sequence',
+ 'OSQ_Q06': ('sequence',
              (('MSH', (1, 1)),
               ('QRD', (1, 1)),
               ('QRF', (0, 1)),
               ('DSC', (0, 1)))),
+ 'OSR_Q06': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('OSR_Q06_RESPONSE', (0, 1)),
+              ('DSC', (0, 1)))),
+ 'PEX_P07': ('sequence',
+             (('MSH', (1, 1)),
+              ('EVN', (1, 1)),
+              ('PID', (1, 1)),
+              ('PD1', (0, 1)),
+              ('NTE', (0, -1)),
+              ('PEX_P07_VISIT', (0, 1)),
+              ('PEX_P07_EXPERIENCE', (1, -1)))),
+ 'PGL_PC6': ('sequence',
+             (('MSH', (1, 1)),
+              ('PID', (1, 1)),
+              ('PGL_PC6_PATIENT_VISIT', (0, 1)),
+              ('PGL_PC6_GOAL', (1, -1)))),
+ 'PIN_I07': ('sequence',
+             (('MSH', (1, 1)),
+              ('PIN_I07_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('PIN_I07_GUARANTOR_INSURANCE', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'PPG_PCG': ('sequence',
+             (('MSH', (1, 1)),
+              ('PID', (1, 1)),
+              ('PPG_PCG_PATIENT_VISIT', (0, 1)),
+              ('PPG_PCG_PATHWAY', (1, -1)))),
+ 'PPP_PCB': ('sequence',
+             (('MSH', (1, 1)),
+              ('PID', (1, 1)),
+              ('PPP_PCB_PATIENT_VISIT', (0, 1)),
+              ('PPP_PCB_PATHWAY', (1, -1)))),
+ 'PPR_PC1': ('sequence',
+             (('MSH', (1, 1)),
+              ('PID', (1, 1)),
+              ('PPR_PC1_PATIENT_VISIT', (0, 1)),
+              ('PPR_PC1_PROBLEM', (1, -1)))),
+ 'PPT_PCL': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QRD', (1, 1)),
+              ('PPT_PCL_PATIENT', (1, -1)))),
+ 'PPV_PCA': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QRD', (1, 1)),
+              ('PPV_PCA_PATIENT', (1, -1)))),
+ 'PRR_PC5': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QRD', (1, 1)),
+              ('PRR_PC5_PATIENT', (1, -1)))),
+ 'PTR_PCF': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QRD', (1, 1)),
+              ('PTR_PCF_PATIENT', (1, -1)))),
+ 'QCK_Q02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QAK', (0, 1)))),
+ 'QRY_A19': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (0, 1)))),
+ 'QRY_PC4': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (0, 1)))),
  'QRY_Q01': ('sequence',
              (('MSH', (1, 1)),
               ('QRD', (1, 1)),
@@ -531,14 +452,304 @@ MESSAGES = {'ACK': ('sequence', (('MSH', (1, 1)), ('MSA', (1, 1)), ('ERR', (0, 1
               ('QRD', (1, 1)),
               ('QRF', (0, 1)),
               ('DSC', (0, 1)))),
- 'QRY_R02': ('sequence',
+ 'QRY_R02': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (1, 1)))),
+ 'QRY_T12': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (0, 1)))),
+ 'RAR_RAR': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('RAR_RAR_DEFINITION', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'RAS_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('RAS_O01_PATIENT', (0, 1)),
+              ('RAS_O01_ORDER', (1, -1)))),
+ 'RCI_I05': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('RCI_I05_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('RCI_I05_OBSERVATION', (0, -1)),
+              ('NTE', (0, -1)))),
+ 'RCL_I06': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('RCL_I06_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('NTE', (0, -1)),
+              ('DSP', (0, -1)),
+              ('DSC', (0, 1)))),
+ 'RDE_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('RDE_O01_PATIENT', (0, 1)),
+              ('RDE_O01_ORDER', (1, -1)))),
+ 'RDO_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('RDO_O01_PATIENT', (0, 1)),
+              ('RDO_O01_ORDER', (1, -1)))),
+ 'RDR_RDR': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('RDR_RDR_DEFINITION', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'RDS_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('RDS_O01_PATIENT', (0, 1)),
+              ('RDS_O01_ORDER', (1, -1)))),
+ 'REF_I12': ('sequence',
+             (('MSH', (1, 1)),
+              ('RF1', (0, 1)),
+              ('REF_I12_AUTHORIZATION', (0, 1)),
+              ('REF_I12_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('GT1', (0, -1)),
+              ('REF_I12_INSURANCE', (0, -1)),
+              ('ACC', (0, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('REF_I12_PROCEDURE', (0, -1)),
+              ('REF_I12_RESULTS', (0, -1)),
+              ('REF_I12_VISIT', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RER_RER': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('RER_RER_DEFINITION', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'RGR_RGR': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('RGR_RGR_DEFINITION', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'RGV_O01': ('sequence',
+             (('MSH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('RGV_O01_PATIENT', (0, 1)),
+              ('RGV_O01_ORDER', (1, -1)))),
+ 'ROR_ROR': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('ROR_ROR_DEFINITION', (1, -1)),
+              ('DSC', (0, 1)))),
+ 'RPA_I08': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('RF1', (0, 1)),
+              ('RPA_I08_AUTHORIZATION', (0, 1)),
+              ('RPA_I08_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('GT1', (0, -1)),
+              ('RPA_I08_INSURANCE', (0, -1)),
+              ('ACC', (0, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('RPA_I08_PROCEDURE', (1, -1)),
+              ('RPA_I08_OBSERVATION', (0, -1)),
+              ('RPA_I08_VISIT', (0, 1)))),
+ 'RPI_I01': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('RPI_I01_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('RPI_I01_GUARANTOR_INSURANCE', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RPL_I02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('RPL_I02_PROVIDER', (1, -1)),
+              ('NTE', (0, -1)),
+              ('DSP', (0, -1)),
+              ('DSC', (0, 1)))),
+ 'RQA_I08': ('sequence',
+             (('MSH', (1, 1)),
+              ('RF1', (0, 1)),
+              ('RQA_I08_AUTHORIZATION', (0, 1)),
+              ('RQA_I08_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('RQA_I08_GUARANTOR_INSURANCE', (0, 1)),
+              ('ACC', (0, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('RQA_I08_PROCEDURE', (0, -1)),
+              ('RQA_I08_OBSERVATION', (0, -1)),
+              ('RQA_I08_VISIT', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RQC_I05': ('sequence',
              (('MSH', (1, 1)),
               ('QRD', (1, 1)),
-              ('QRF', (1, 1)),
+              ('QRF', (0, 1)),
+              ('RQC_I05_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('GT1', (0, -1)),
+              ('NTE', (0, -1)))),
+ 'RQC_I06': ('sequence',
+             (('MSH', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('RQC_I06_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('GT1', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RQI_I01': ('sequence',
+             (('MSH', (1, 1)),
+              ('RQI_I01_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('RQI_I01_GUARANTOR_INSURANCE', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RQP_I04': ('sequence',
+             (('MSH', (1, 1)),
+              ('RQP_I04_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('NK1', (0, -1)),
+              ('GT1', (0, -1)),
+              ('NTE', (0, -1)))),
+ 'RQQ_Q01': ('sequence', (('MSH', (1, 1)), ('ERQ', (1, 1)), ('DSC', (0, 1)))),
+ 'RRA_O02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('RRA_O02_RESPONSE', (0, 1)))),
+ 'RRD_O02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('RRD_O02_PATIENT', (0, 1)))),
+ 'RRG_O02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('RRG_O02_RESPONSE', (0, 1)))),
+ 'RRI_I12': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (0, 1)),
+              ('RF1', (0, 1)),
+              ('RRI_I12_AUTHORIZATION', (0, 1)),
+              ('RRI_I12_PROVIDER', (1, -1)),
+              ('PID', (1, 1)),
+              ('ACC', (0, 1)),
+              ('DG1', (0, -1)),
+              ('DRG', (0, -1)),
+              ('AL1', (0, -1)),
+              ('RRI_I12_PROCEDURE', (0, -1)),
+              ('RRI_I12_RESULTS', (0, -1)),
+              ('RRI_I12_VISIT', (0, 1)),
+              ('NTE', (0, -1)))),
+ 'RRO_O02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('RRO_O02_RESPONSE', (0, 1)))),
+ 'SIU_S12': ('sequence',
+             (('MSH', (1, 1)),
+              ('SCH', (1, 1)),
+              ('NTE', (0, -1)),
+              ('SIU_S12_PATIENT', (0, -1)),
+              ('SIU_S12_RESOURCES', (1, -1)))),
+ 'SPQ_Q01': ('sequence',
+             (('MSH', (1, 1)),
+              ('SPR', (1, 1)),
+              ('RDF', (0, 1)),
+              ('DSC', (0, 1)))),
+ 'SQM_S25': ('sequence',
+             (('MSH', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('SQM_S25_REQUEST', (0, 1)),
+              ('DSC', (0, 1)))),
+ 'SQR_S25': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QAK', (1, 1)),
+              ('SQR_S25_SCHEDULE', (0, -1)),
+              ('DSC', (0, 1)))),
+ 'SRM_S01': ('sequence',
+             (('MSH', (1, 1)),
+              ('ARQ', (1, 1)),
+              ('APR', (0, 1)),
+              ('NTE', (0, -1)),
+              ('SRM_S01_PATIENT', (0, -1)),
+              ('SRM_S01_RESOURCES', (1, -1)))),
+ 'SRR_S01': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('SRR_S01_SCHEDULE', (0, 1)))),
+ 'SUR_P09': ('sequence', (('MSH', (1, 1)), ('SUR_P09_FACILITY', (1, -1)))),
+ 'TBR_Q01': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('ERR', (0, 1)),
+              ('QAK', (1, 1)),
+              ('RDF', (1, 1)),
+              ('RDT', (1, -1)),
               ('DSC', (0, 1)))),
  'UDM_Q05': ('sequence',
              (('MSH', (1, 1)),
               ('URD', (1, 1)),
               ('URS', (0, 1)),
               ('DSP', (1, -1)),
-              ('DSC', (1, 1))))}
+              ('DSC', (0, 1)))),
+ 'VQQ_Q01': ('sequence',
+             (('MSH', (1, 1)),
+              ('VTQ', (1, 1)),
+              ('RDF', (0, 1)),
+              ('DSC', (0, 1)))),
+ 'VXQ_V01': ('sequence', (('MSH', (1, 1)), ('QRD', (1, 1)), ('QRF', (0, 1)))),
+ 'VXR_V03': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('PID', (1, 1)),
+              ('PD1', (0, 1)),
+              ('NK1', (0, -1)),
+              ('VXR_V03_PATIENT_VISIT', (0, 1)),
+              ('VXR_V03_INSURANCE', (0, -1)),
+              ('VXR_V03_ORDER', (0, -1)))),
+ 'VXU_V04': ('sequence',
+             (('MSH', (1, 1)),
+              ('PID', (1, 1)),
+              ('PD1', (0, 1)),
+              ('NK1', (0, -1)),
+              ('VXU_V04_PATIENT', (0, 1)),
+              ('VXU_V04_INSURANCE', (0, -1)),
+              ('VXU_V04_ORDER', (0, -1)))),
+ 'VXX_V02': ('sequence',
+             (('MSH', (1, 1)),
+              ('MSA', (1, 1)),
+              ('QRD', (1, 1)),
+              ('QRF', (0, 1)),
+              ('VXX_V02_PATIENT', (1, -1))))}
